# Security Policy

## Reporting a Vulnerability

If you discover a security vulnerability, please report it responsibly.

- Email: martin@klein.business
- Provide a clear description, steps to reproduce, and potential impact.

We aim to acknowledge reports within 2 business days and provide a resolution
plan as soon as practical.

Do not open public issues for security vulnerabilities.
